# Copyright (c) 2000-2011, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%bcond_with gcj_support
%bcond_without repolib

%if %with gcj_support
%define gcj_support 1
%else
%define gcj_support 0
%endif

%define repodir %{_javadir}/repository.jboss.com/sun-ws-metadata/%{namedversion}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src

%define section free
%define wsmdver 2.0

%define reltag MR1
%global namedversion 1.0-%{reltag}

Name:           sun-ws-metadata-2.0-api
Version:        1.0.%{reltag}
Release:        11%{?dist}
Epoch:          0
Summary:        Web Services Metadata 2.0 MR API
License:        CDDL
Group:          Development/Libraries/Java
URL:            https://jsr250.dev.java.net/
Source0:        http://download.java.net/maven/1/javax.jws/java-sources/jsr181-api-1.0-MR1-sources.jar
Source1:        http://download.java.net/maven/1/javax.jws/poms/jsr181-api-1.0-MR1.pom
Source2:        CDDLv1.0.html
Source3:        sun-ws-metadata-2.0-api-build.properties
Source4:        sun-ws-metadata-2.0-api-build.xml
Source5:        %{name}-component-info.xml
Patch0:         %{name}-build_xml.patch

Provides:       ws_metadata_api = 0:%{wsmdver}
Provides:       ws_metadata_2_0_api = 0:%{version}-%{release}

Requires(post): jpackage-utils
Requires(post): %{_sbindir}/update-alternatives
Requires(postun): jpackage-utils
Requires(preun): %{_sbindir}/update-alternatives
# To create content for maven2-brew
BuildRequires:  maven2-plugin-deploy
Requires:       jpackage-utils
BuildRequires:  ant >= 0:1.6.5
BuildRequires:  java-devel >= 0:1.5.0
BuildRequires:  jpackage-utils >= 0:1.7.3
%if %{gcj_support}
BuildRequires:  java-gcj-compat-devel
%else
BuildArch:      noarch
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

%description
Web Services Metadata for the Java Platform 2.0 Maintenance Release
according to JSR-181.
This is JSR-181 MR1 in fact, which changed its version from 1.0 to 2.0.

%package javadoc
Summary:        Javadoc for %{name}
Group:          Development/Documentation
Provides:       ws-metadata-javadoc = 0:%{wsmdver}

%description javadoc
%{summary}.

%if %with repolib
%package repolib
Summary:        Artifacts to be uploaded to a repository library
Group:          Development/Libraries/Java

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%prep
%setup -q -c 
mkdir -p src/java
mv javax src/java
cp -p %{SOURCE3} build.properties
cp -p %{SOURCE4} build.xml
%patch0 -b .sav0

%build
export CASSPATH=
export OPT_JAR_LIST=:
%{ant} release

%install
rm -rf %{buildroot}

# jars
mkdir -p %{buildroot}%{_javadir}
cp -p jws.jar %{buildroot}%{_javadir}/%{name}-%{namedversion}.jar
%{__ln_s} %{name}-%{namedversion}.jar  %{buildroot}%{_javadir}/jws-%{namedversion}.jar
(cd %{buildroot}%{_javadir} && for jar in *-%{namedversion}*; do %{__ln_s} ${jar} `/bin/echo ${jar} | %{__sed} "s|-%{namedversion}||g"`; done)

/bin/touch %{buildroot}%{_javadir}/ws_metadata_api.jar
/bin/touch %{buildroot}%{_javadir}/ws_metadata_2_0_api.jar

# poms
mkdir -p %{buildroot}%{_datadir}/maven2/poms
cp -p %{SOURCE1} %{buildroot}%{_datadir}/maven2/poms/JPP-%{name}.pom
%add_to_maven_depmap javax.jws jsr181-api %{namedversion} JPP %{name}

# javadoc
mkdir -p %{buildroot}%{_javadocdir}/%{name}-%{namedversion}
cp -pr build/release/docs/javadocs/* %{buildroot}%{_javadocdir}/%{name}-%{namedversion}
ln -s %{name}-%{namedversion} %{buildroot}%{_javadocdir}/%{name}

mkdir -p %{buildroot}%{_docdir}/%{name}-%{namedversion}
cp -p %{SOURCE2} %{buildroot}%{_docdir}/%{name}-%{namedversion}/CDDLv1.0.html

%if %{gcj_support}
%{_bindir}/aot-compile-rpm
%endif

%if %with repolib
mkdir -p %{buildroot}%{repodir}
mkdir -p %{buildroot}%{repodirlib}
mvn-jpp deploy:deploy-file \
-DgroupId=javax.jws \
-DartifactId=jsr181-api \
-Dversion=%{namedversion} \
-Dpackaging=jar \
-Dfile=%{buildroot}%{_javadir}/%{name}-%{namedversion}.jar \
-DpomFile=%{SOURCE1} \
-Durl=file://%{buildroot}%{_javadir}/repository.jboss.com/maven2-brew/ \
-DrepositoryId=jboss-releases
cp -p %{SOURCE5} %{buildroot}%{repodir}/component-info.xml
sed -i 's/@VERSION@/%{namedversion}-brew/g' $RPM_BUILD_ROOT%{repodir}/component-info.xml
tag=`echo %{name}-%{version}-%{release} | sed 's|\.|_|g'`
sed -i "s/@TAG@/$tag/g" $RPM_BUILD_ROOT%{repodir}/component-info.xml
mkdir -p %{buildroot}%{repodirsrc}
cp -p %{SOURCE0} %{buildroot}%{repodirsrc}
cp -p %{SOURCE2} %{buildroot}%{repodirsrc}
cp -p %{SOURCE3} %{buildroot}%{repodirsrc}
cp -p %{SOURCE4} %{buildroot}%{repodirsrc}
cp -p %{SOURCE1} %{buildroot}%{repodirlib}/jsr181-api.pom
cp -p %{PATCH0} %{buildroot}%{repodirsrc}
cp -p %{buildroot}%{_javadir}/%{name}.jar %{buildroot}%{repodirlib}/jsr181-api.jar
%{__install} -p -m 644 %{SOURCE1} %{buildroot}%{repodirlib}/jsr181-api.pom
%endif

%clean
rm -rf %{buildroot}

%post
%{_sbindir}/update-alternatives --install %{_javadir}/ws_metadata_2_0_api.jar ws_metadata_2_0_api %{_javadir}/%{name}.jar 20000
%{_sbindir}/update-alternatives --install %{_javadir}/ws_metadata_api.jar ws_metadata_api %{_javadir}/%{name}.jar 20000
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif
%update_maven_depmap

%preun
if [ "$1" = "0" ]; then
    %{_sbindir}/update-alternatives --remove ws_metadata_2_0_api %{_javadir}/%{name}.jar
    %{_sbindir}/update-alternatives --remove ws_metadata_api %{_javadir}/%{name}.jar
fi

%postun
%update_maven_depmap
%if %{gcj_support}
if [ -x %{_bindir}/rebuild-gcj-db ]
then
  %{_bindir}/rebuild-gcj-db
fi
%endif

%files
%defattr(0644,root,root,0755)

%doc %{_docdir}/%{name}-%{namedversion}/CDDLv1.0.html
%ghost %{_javadir}*/ws_metadata_2_0_api.jar
%ghost %{_javadir}*/ws_metadata_api.jar
%{_javadir}*/%{name}-%{namedversion}.jar
%{_javadir}*/%{name}.jar
%{_javadir}*/jws-%{namedversion}.jar
%{_javadir}*/jws.jar
%ghost %{_javadir}*/ws_metadata_2_0_api.jar
%ghost %{_javadir}*/ws_metadata_api.jar
%{_datadir}/maven2/poms/JPP-%{name}.pom
%{_mavendepmapfragdir}/%{name}
%if %{gcj_support}
%dir %{_libdir}/gcj/%{name}
%attr(-,root,root) %{_libdir}/gcj/%{name}/%{name}-%{namedversion}.jar.*
%endif

%files javadoc
%defattr(0644,root,root,0755)
%{_javadocdir}/%{name}-%{namedversion}
%{_javadocdir}/%{name}

%if %with repolib
%files repolib
%defattr(0644,root,root,0755)
%dir %{_javadir}*
%exclude %dir %{_javadocdir}
%{_javadir}*/repository.jboss.com
%endif

%changelog
* Mon Apr 11 2011 David Walluck <dwalluck@redhat.com> 0:1.0.MR1-11
- own alternatives links
- fix repolib option
- fix maven deps
- fix dir ownership

* Fri Apr 08 2011 Martha Benitez <mbenitez@redhat.com> - 0:1.0.MR1-10.1
- Fix version to include MR1

* Thu Mar 10 2011 Hui Wang <huwang@redhat.com> 0:1.0.MR1-10
- Fix %%repodir macros

* Thu Mar 10 2011 Hui Wang <huwang@redhat.com> 0:1.0.MR1-9
- Fix version

* Thu Dec 09 2010 Hui Wang <huwang@redhat.com> 0:1.0.MR1-8
- Add upload.sh and content of maven2-brew to repolib
- Fix %%files for signed jars

* Wed Sep 08 2010 David Walluck <dwalluck@redhat.com> 0:1.0.MR1-7
- rebuild

* Wed Sep 08 2010 David Walluck <dwalluck@redhat.com> 0:1.0.MR1-6
- fix alternatives
- fix maven support
- fix POM name
- add jws.jar symlink
- fix GCJ support
- fix javadoc
- fix repolib

* Fri May 07 2010 Martha Benitez <mbenitez@redhat.com> - 0:1.0.MR1-5.1
- rebuilt

* Tue Apr 06 2010 Hui Wang <huwang@redhat.com> - 0:1.0.MR1-5
- Rebuild
- Change BR: BuildRequires:  java-devel = 0:1.5.0  to BR: BuildRequires:  java-devel >= 0:1.5.0
- Change BR: export JAVA_HOME=/usr/lib/jvm/java-1.5.0 to BR: export JAVA_HOME=/usr/lib/jvm/java-1.6.0

* Fri Nov 20 2009 Martha Benitez <mbenitez@redhat.com> - 0:1.0.MR1-4
- Add manifest patch to repolib

* Fri Nov 20 2009 Martha Benitez <mbenitez@redhat.com> - 0:1.0.MR1-3
- Add repolib
- Add patch to fill in manifest.mf in jar

* Mon Dec 08 2008 Will Tatam <will.tatam@red61.com> 1.0.MR1-2
- Auto rebuild for JPackage 5 in mock

* Thu Nov 08 2007 Ralph Apel <r.apel at r-apel.de> - 0:1.0.MR1-1jpp
- First release

